@@ -1,4 +1,4 @@
-use sdb::{direct_repr, Db, DbU, Storable, Tx, UnsizedStorable};
+use sdb::{sdb, Db, DbU, Storable, Tx, UnsizedStorable};
 use static_init::dynamic;
 use std::env;
 use std::path::Path;
@@ -37,7 +37,7 @@ pub static DB0: Db<'static, u64, u64> = TX.db(0);
 #[derive(Default, Eq, PartialEq, PartialOrd, Ord, Hash, Clone, Copy, Debug)]
 pub struct Hash(pub [u8; 2]);
 
-direct_repr!(Hash);
+sdb!(Hash);
 
 #[dynamic]
 pub static DB1: Db<'static, u64, Hash> = TX.db(1);
@@ -54,7 +54,7 @@ pub struct Data {
   pub id: u64,
 }
 
-direct_repr!(Data);
+sdb!(Data);
 
 #[dynamic]
 pub static DB4: Db<'static, u64, Data> = TX.db(4);
